# Overview

This charm provides a complete Ubuntu mirror service, handling fetching the
data via rsync from a master server (updates either triggered on-demand using
ssh or by cron), and making it available through http, ftp and rsync.

It can work alongside a log-archive subordinate charm to transfer logs to
a suitable storage host.

# Usage

Assuming you already have a bootstrapped Juju environment, the charm can
be deployed using:

    juju deploy ubuntu-mirror

Once deployed, you will need to configure it for your local environment.
An Ubuntu archive mirror can be created using the following commands:

    juju config ubuntu-mirror mirror_ubuntu_name="myhost.mydomain.com"
    juju config ubuntu-mirror mirror_ubuntu_sync_time="0 1 * * *"
    juju config ubuntu-mirror role_map='{"myhost":["ubuntu"]}'

Replace "myhost" with the hostname of your server and "myhost.mydomain.com" with
its fully qualified domain name (FQDN).

The "role_map" variable tells the charm what type of mirror you want to create
(currently, this can be any of "ubuntu" (a mirror of archive.ubuntu.com),
"releases" (a mirror of releases.ubuntu.com), "cdimage" (a mirror of
cdimage.ubuntu.com" or "ports" (a mirror of ports.ubuntu.com)  If you have a
sufficiently large server, multiple roles can be assigned to one server
(`role_map='{"myhost":["ubuntu","cdimage"]}'` for example).

If you have more than one server, you should list each one (e.g. `role_map='{"host1":["cdimage","ubuntu"],"host2":["releases"]}'`).

The "mirror_ubuntu_name" variable is the name the webserver will use for
the Ubuntu mirror.  In the above example, it would answer requests for
`http://myhost.mydomain.com`.

The "mirror_ubuntu_sync_time" variable tells the charm what time it should
update.  In the above example, the update would happen every day at 1am.

There are a number of variables that can be set on a per-role basis.  They
all follow the pattern `mirror_<rolename>_<variable>`, so if we were setting up
a cdimage mirror, we would use "mirror_cdimage_name" and
"mirror_cdimage_sync_time".

To cater for rsync servers that require authentication, there is a per-role
variable, `mirror_<rolename>_rsync_auth`.  If you don't need to authenticate
against your upstream mirror, leave this alone, the defaults will be fine.
If you do need to authenticate, this variable should be used like this:

    juju config ubuntu-mirror mirror_cdimage_rsync_auth='{"myhost":{"user":"eric", "password":"YXBwbGVzCg=="}}'

The password value is just a Base64-encoded string, just in case it needs to
contain any special characters (it also helps avoid people casually reading
passwords over your shoulder when you run `juju config`).

As with role_map (above), if you have multiple servers they should all be listed
(e.g. `mirror_cdimage_rsync_auth='{"host1":{"user":"eric","password":"YXBwbGVzCg=="},"host2":{"user":"frank","password":"b3Jhbmdlcwo="}}'`).

For simplicity, if all of your servers authenticate with the same username
and password, you can use: `{"<<all>>":{"user":"eric","password":"YXBwbGVzCg=="}}`.
